#!/bin/bash

#
# Script
#
# g4cParallelSimulationParametersSetup.sh
#
#    imposta i parametri della simulazione parallela
#

###################################################################
#
# Istruzioni:
#   impostare opportunamente i parametri di questa sezione
#
###################################################################

#
# <verbose>
#   i valori ammessi per il parametro sono 0 o 1.
#   Se 1 attiva la modalita' verbose di esecuzione dello script
#
verbose=1

#
# <macroFileAbsolutePath>
#   path assoluto del file di macro a partire dal quale vengono generati
#   quelli per le simulazioni eseguite dai singoli job 
#
# ATTENZIONE
#   il file deve specificare il numero di eventi processati da ogni job
#   piuttosto che quello complessivamente coinvolto nella simulazione
#
macroFileAbsolutePath=/home/un5u5p3ct3db055/g4cSimulation/g4cParallelSimulation/try.mac

#
# <workingDirectoryRelativePath>
#   path relativo alla directory g4cParallelSimulation di quella
#   di lavoro che contiene le subdirectory assegnate ai job che
#   realizzano la simulazione, il file con le informazioni relative
#   ai loro istanti di sottomissione e di completamento e il file di
#   output per la modalita' verbose
#
# ATTENZIONE
#    simulazioni diverse richiedono la specifica di
#    diversi workingDirectoryRelativePath
#
workingDirectoryRelativePath=./testDirTV

#
# <totalNumberOfJobs>
#   numero totale dei job che realizzano la simulazione parallela.
#   Deve preferibilmente essere minore o uguale del numero di host
#   impegnati moltiplicato per il minimo numero di core riservati alla
#   simulazione su ogni host
#
totalNumberOfJobs=6

#
# <simulationExecutableAbsolutePath>
#   path assoluto dell'eseguibile da assegnare ad ogni job
#   della simulazione parallela
#
simulationExecutableAbsolutePath=/home/un5u5p3ct3db055/Athena2017-Aukaptonshield-10.4-SPLv2-analysismanagertest-build/athena

#
# <jobsTimeOut>
#   numero di secondi dall'inizio della sua esecuzione trascorso il quale
#   ogni job viene interrotto. Se 0 inibisce il time out
#
jobsTimeOut=60

#
# <parallelJobsPerHost>
#   numero dei job eseguiti in parallelo su ognuno degli host impegnati nella
#   simulazione. Non deve essere maggiore del minimo numero di core riservati
#   alla simulazione su ogni host 
#
parallelJobsPerHost=3

#
# <hostsList>
#   elenco dei nomi degli host impegnati nella simulazione, separati da
#   virgola e senza blank
#
hostsList=athenaXifu01,athenaXifu02,athenaXifu03

#
# <geant4EnvVariablesSetUp>
#   path assoluto dello script che setta le variabili di ambiente
#   di Geant4 per la simulazione
#
geant4EnvVariablesSetUp=/usr/local/geant4/10.4.3/bin/geant4.sh

###################################################################
#
# Istruzioni:
#   non modificare le impostazioni dei parametri di questa sezione
#   se non strettamente necessario
#
###################################################################

#
# <tspQueuesPositioning>
#   variabile simbolica che, definendo il posizionamento del file
#   di informazioni per la coda di task gestita da tsp 
#   (task spooler), ne permette l'accesso all'host che la
#   utilizza per gestire l'esecuzione parallela dei job.
#   Al file in questione, memorizzato su ogni host nella directory
#   "\tmp",  assegnato il nome della working directory seguito
#   dal suffisso ".tmp"
#
tspQueuesPositioning="TS_SOCKET=/tmp/$(basename $workingDirectoryRelativePath.tsp)"

#
# <beamCmdString>
#   stringa che nel file di macro individua la direttiva che 
#   setta il numero degli eventi processati da ogni job
#
beamCmdString=/run/beamOn

#
# <setSeedsString>
#   stringa che nel file di macro individua la direttiva che setta
#   il seed di generazione casuale di eventi
#
setSeedsString=/random/setSeeds

#
# <verbOutputFileName>
#   nome del file di output, nella working directory, per la
#   modalita' verbose
#   
verbOutputFileName=verbOutputFile.txt

#
# <jobsRuntimeFileName>
#   nome del file, nella working directory, nel
#   quale vengono memorizzati gli istanti di sottomissione e di
#   completamento di tutti i job che realizzano la simulazione 
#
jobsRuntimeFileName=jobsRuntimeFile.res

#
# <jobRuntimeFileName>
#   nome del file, nella directory assegnata ad ogni job, nel
#   quale vengono memorizzati i suoi istanti di sottomissione 
#   e di completamento
#
jobRuntimeFileName=jobRuntimeFile.log

###################################################################
#
# Istruzioni:
#   non modificare le impostazioni dei parametri di questa sezione
#
###################################################################

#
# <scriptsRelativePath>
#   path relativo alla directory g4cParallelSimulation
#   di quella che contiene gli script per le funzionalita'
#   principali che realizzano la simulazione
#
scriptsRelativePath=.

#
# <errRelativePath>
#   path relativo alla directory g4cParallelSimulation
#   di quella che contiene gli script per i messaggi
#   di errore
#
errRelativePath=./errorMessages

#
# <verbRelativePath>
#   path relativo alla directory g4cParallelSimulation 
#   di quella che contiene gli script di gestione 
#   della modalita' verbose
#
verbRelativePath=./verboseMessages

#
# <helpRelativePath>
#   path relativo alla directory g4cParallelSimulation
#   di quella che contiene i messaggi di aiuto alla
#   interazione con la simulazione
#
helpRelativePath=./helpMessages

###############################################################
###############################################################
###############################################################



